| Title: | Companion Package for Rostools R Workshops |
|---|---|
| Description: | Contains the helper functions and other files to make it easier for learners during (and after) the workshop. |
| Authors: | Luke Johnston [aut, cre] (ORCID: <https://orcid.org/0000-0003-4169-2616>) |
| Maintainer: | Luke Johnston <[email protected]> |
| License: | MIT + file LICENSE |
| Version: | 0.8.3 |
| Built: | 2026-06-04 11:09:48 UTC |
| Source: | https://github.com/rostools/r3 |
DESCRIPTION filesCompares with all the workshops
admin_update_deps()admin_update_deps()
Doesn't output anything, used for the side effect to update the
DESCRIPTION file.
Runs checks on your system for R, RStudio, and Git.
check_r_version() check_rstudio_version() check_git_config() check_setup() check_project_setup_intermediate() check_project_setup_advanced()check_r_version() check_rstudio_version() check_git_config() check_setup() check_project_setup_intermediate() check_project_setup_advanced()
Prints information on given check.
check_r_version(): Check version of R that is installed.
check_rstudio_version(): Check version of RStudio that is installed.
check_git_config(): Checks your computer's Git config settings.
check_setup(): Check your setup in preparation for the workshop.
check_project_setup_intermediate(): Check your project setup for the files and folders created.
check_project_setup_advanced(): For the advanced workshop: Check your project setup
for the files and folders created during the pre-workshop tasks.
docs/ folder.Make a draft of a Quarto document to use for the workshops.
create_learning_qmd() create_cleaning_qmd() create_sandbox_qmd()create_learning_qmd() create_cleaning_qmd() create_sandbox_qmd()
Creates a Quarto Markdown document in the docs/ folder.
create_learning_qmd(): Create a learning.qmd file in the docs/ folder.
create_cleaning_qmd(): Create a cleaning.qmd file in the docs/ folder.
create_sandbox_qmd(): Create a sandbox.qmd file in the docs/ folder.
Fix some Git remote issues that occur during the workshop.
fix_git_remotes()fix_git_remotes()
Used for the side effect of connecting to Git. Returns NULL invisibly.
The allowed versions are those that are at maximum a year old from today, sorted by the oldest first.
get_allowed_r_versions()get_allowed_r_versions()
A character vector of allowed R versions.
get_allowed_r_versions()get_allowed_r_versions()
The versions are those that are at a maximum one year old from today, sorted by the oldest first.
get_allowed_rstudio_versions()get_allowed_rstudio_versions()
A character vector of allowed RStudio versions.
get_allowed_rstudio_versions()get_allowed_rstudio_versions()
Set the user's git configuration.
setup_git_config()setup_git_config()
Modifies global git configuration.
Set some Git config settings like main as default and rebase as false.
setup_git_settings()setup_git_settings()
Invisible, values of previous settings.